/**
 * @file
 * PhotoShelter click to select functionality.
 */

(function ($, Drupal) {

  'use strict';

  /**
   * Allows users to select an element which checks a hidden checkbox.
   * Taken from the media library.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches behavior for selecting photoshelter media item.
   */
  Drupal.behaviors.photoshelterClickToSelect = {
    attach(context) {
      $(once('photoshelter-click-to-select', '.js-click-to-select-trigger', context))
        .on('click', (event) => {
        // Links inside the trigger should not be click-able.
        event.preventDefault();
        // Click the hidden checkbox when the trigger is clicked.
        const $input = $(event.currentTarget)
          .closest('.js-click-to-select')
          .find('.js-click-to-select-checkbox input');
        $input.prop('checked', !$input.prop('checked')).trigger('change');
      });

      $(once('photoshelter-click-to-select-checkbox', '.js-click-to-select-checkbox input', context))
        .on('change', ({ currentTarget }) => {
          $(currentTarget)
            .closest('.js-click-to-select')
            .toggleClass('checked', $(currentTarget).prop('checked'));
        })
        // Adds is-focus class to the click-to-select element.
        .on('focus blur', ({ currentTarget, type }) => {
          $(currentTarget)
            .closest('.js-click-to-select')
            .toggleClass('is-focus', type === 'focus');
        });

      // Adds hover class to the click-to-select element.
      $(once('photoshelter-click-to-select-hover', '.js-click-to-select-hover, .js-click-to-select-checkbox', context))
        .on('mouseover mouseout', ({ currentTarget, type }) => {
        $(currentTarget)
          .closest('.js-click-to-select')
          .toggleClass('is-hover', type === 'mouseover');
      });
    },
  };

})(jQuery, Drupal);
