/**
 * @file
 * PhotoShelter metadata tooltip.
 */

(function ($, Drupal) {

  'use strict';

  /**
   * Allows the user to toggle the metadata display in a tooltip for photoshelter media items.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches behavior for displaying the metadata tooltip.
   */
  Drupal.behaviors.photoshelterTooltip = {
    attach(context) {
      $(once('photoshelter-metadata-tooltip-click', '.photoshelter-item__metadata-button', context)).on('click', (event) => {
        event.preventDefault();
        if (!$(event.currentTarget).hasClass('expanded')) {
          showTooltip($(event.currentTarget));
          return false;
        }
      });

      function showTooltip(button) {
        collapseAllTooltip();
        button.parent().find('.photoshelter-item__metadata-content-container').fadeIn(400);
        button.addClass('expanded').attr('aria-expanded', 'true');

        // Out of focus event.
        $(document).bind('click.photoshelter-tooltip-focus', function(e) {
          var container_class = 'photoshelter-item__metadata-content-container';
          var $focused = $(':focus');
          var $target = $(e.target);
          if (!$focused.hasClass(container_class) || !$target.hasClass(container_class) || !$target.parents('.' + container_class).length) {
            hideTooltip(button);
          }
        });

        // "Keydown" event for arrow navigation.
        $(document).bind('keydown.photoshelter-tooltip-focus', function (e) {
          let code = e.keyCode || e.which;

          if (code === 27) {
            // "Esc" key event.
            hideTooltip(button);
          }
        });
      }

      function hideTooltip(button) {
        button.parent().find('.photoshelter-item__metadata-content-container').fadeOut();
        button.removeClass('expanded').attr('aria-expanded', 'false');
        $(document).unbind('click.photoshelter-tooltip-focus');
        $(document).unbind('keydown.photoshelter-tooltip-focus');
      }

      function collapseAllTooltip() {
        $('.photoshelter-item__metadata-button', context).removeClass('expanded').attr('aria-expanded', 'false');
        $('.photoshelter-item__metadata-content-container', context).fadeOut();
      }
    }
  };

})(jQuery, Drupal);
