<?php

declare(strict_types=1);

namespace Drupal\photoshelter\Exception;

/**
 * Defines a PhotoShelter API exception.
 */
final class PhotoshelterException extends \Exception {

  /**
   * Request parameters.
   *
   * @var array
   */
  private array $requestParameters = [];

  /**
   * Object constructor.
   *
   * Error codes:
   *   1 - API key is missing,
   *   2 - required OAuth token is missing for this request,
   *   3 - unsupported method,
   *   4 - oAuth token requested without code provided and no refresh token
   *       is available,
   *   5 - trying to request an oAuth token without a registered client,
   *   6 - unauthorized response received,
   *   7 - missing path parameter,
   *   8 - unable to save upload (internal error),
   *   9 - API call limit reached,
   *   10 - the current user doesn't have the 'use photoshelter' permission,
   *   0 - other.
   */
  public function __construct(string $message = "", array $request_parameters = [], $code = 0, ?Throwable $previous = NULL) {
    parent::__construct($message, $code, $previous);

    $this->request_parameters = $request_parameters;
  }

  /**
   * Parameters getter.
   *
   * @return mixed[]
   *   The parameters.
   */
  public function getRequestParameters(): array {
    return $this->request_parameters;
  }

  /**
   * Gets full debug information for the throwed exception.
   *
   * @return string
   *   As in description.
   */
  public function getFullInfo(): string {
    $info = $this->code . ': ' . $this->message;
    if (\count($this->request_parameters) !== 0) {
      $info .= ' ' . \PHP_EOL . 'Request: ' . \PHP_EOL . '<pre>' . \json_encode($this->request_parameters, \JSON_UNESCAPED_SLASHES | \JSON_PRETTY_PRINT) . '</pre>';
    }
    return $info;
  }

}
