<?php

declare(strict_types=1);

namespace Drupal\photoshelter;

use Drupal\Core\Link;
use Drupal\photoshelter\Exception\PhotoshelterException;

trait UserErrorTrait {

  /**
   * Must be compatible with Drupal\Core\Controller\ControllerBase.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  private function getUserTabLink(): Link {
    if ($this->currentUser === NULL) {
      $this->currentUser = \Drupal::currentUser();
    }
    return Link::createFromRoute($this->t('select your organization'), 'entity.user.photoshelter', ['user' => $this->currentUser->id()], ['attributes' => ['target' => '_blank']]);
  }

  private function getAuthLink(string $target = '_self'): Link {
    return Link::createFromRoute($this->t('Please authenticate'), 'photoshelter.oauth', [], [
      'query' => $target === '_blank' ? [] : $this->getDestinationArray(),
      'attributes' => [
        'target' => $target,
      ],
    ]);
  }

  private function userError(PhotoshelterException $e, string $target = '_self'): void {
    $error_code = $e->getCode();
    if ($error_code === 1) {
      $message = $this->t('@link a PhotoShelter API key.', [
        '@link' => Link::createFromRoute($this->t('Please provide'), 'photoshelter.configuration', [], [
          'query' => $target === '_blank' ? [] : $this->getDestinationArray(),
          'attributes' => [
            'target' => $target,
          ],
        ])->toString(),
      ]);
      $this->messenger()->addWarning($message);
    }
    elseif ($error_code === 2) {
      $message = $this->t('@link using your PhotoShelter account.', [
        '@link' => $this->getAuthLink($target)->toString(),
      ]);
      $this->messenger()->addWarning($message);
    }
    elseif ($error_code === 6) {
      $message = $this->t('You have been logged out of PhotoShelter. @link using your PhotoShelter account.', [
        '@link' => $this->getAuthLink($target)->toString(),
      ]);
      $this->messenger()->addWarning($message);
    }
    elseif ($error_code === 9) {
      $request_options = $e->getRequestParameters();
      $this->messenger()->addError($this->t('Too many recent calls to PhotoShelter API, please retry after @number seconds.', [
        '@number' => $request_options['retry_after'][0],
      ]));
    }
    elseif ($error_code === 10) {
      $this->messenger()->addError($this->t('You don\'t have permissions to use PhotoShelter API, please contact your site administrator.'));
    }
    else {
      $this->messenger()->addError($this->t('An unexpected error occurred. Please contact your site administrator.'));
      $this->logger->error($e->getFullInfo());
    }
  }

}
